# LingRex: Linguistic Reconstruction with LingPy

LingRex offers the code needed for the automatic inference of sound correspondence patterns as described in the forthcoming paper.

> List, Johann-Mattis (forthcoming): Automatic inference of sound corresponndence patterns across multiple languages. *Computational Linguistics*. Preprint available at [biorxiv](https://doi.org/10.1101/434621). 

When using this package in your research, please make sure to quote the paper accordingly, and quot ethe software package as follows:

> List, Johann-Mattis (2018): LingRex: Linguistic reconstruction with LingPy. Version 0.1.1. Jena: Max Planck Institute for the Science of Human History.


## Installation

Install lingpy in the required version by typing:

```shell
$ pip install -r pip-requirements.txt
```

Then install the package by typing:

```shell
$ python setup.py develop
```

 

